/*--------------------------------------------------------------------
 * 
 * This file is part of libRadtran.
 * Copyright (c) 1997-2002 by Arve Kylling and Bernhard Mayer.
 * 
 * ######### Contact info: http://www.libradtran.org #########
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License   
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.        
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of  
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the   
 * GNU General Public License for more details.                    
 * 
 * You should have received a copy of the GNU General Public License          
 * along with this program; if not, write to the Free Software                
 * Foundation, Inc., 59 Temple Place - Suite 330, 
 * Boston, MA 02111-1307, USA.
 *--------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "../src_c/getopt.h"

#ifndef PI
#define PI 3.14159265358979323846264338327
#endif

static void usage();

int main(int argc, char **argv) 
{

  int c=0;
  double resolution=0.0;

  double ang, ang_start, ang_end, func=0, x;
  int i, n_points=0, type=1, angunit=1;

  while ((c=getopt (argc, argv, "hr:a:t:")) != EOF)  {
    switch(c)  {
    case 'r': 
      resolution = atof(optarg);
      break;
    case 't': 
      type = atoi(optarg);
      break;
    case 'a': 
      angunit = atoi(optarg);
      break;
    case 'h':  /* Guess what */
      usage();
      return (-1);
      break;
    default:
      usage();
      return (-1);
    }
  }
   
  ang_start = 180;
  ang_end   = 0;
  n_points     = (int) (abs(ang_end-ang_start)/resolution) + 1;
  for (i=0;i<n_points;i++) {
    ang    = ang_start - i*resolution;
    switch (type) {
    case 1: 
      func   = (double) cos(PI*ang/180.);
      break;
    case 2: 
    case 3: 
      func   = (double) 1;
      break;
    }
    if ( ang < 90 && type != 3) func = 0;
    x = ang;
    if (angunit ==2 ) x=cos(PI*ang/180.);
    printf("%10.6f %10.6f\n", x, fabs(func));
  }
  return 0;   /* if o.k. */
}

/*************************************************************/
/* print usage information                                   */
/*************************************************************/

static void usage()
{
  fprintf (stderr, "\nOutputs to stdout the angle and \n");
  fprintf (stderr, "corresponding value for a given angular response.\n");
  fprintf (stderr, "The output angles follow disort conventions.\n");
  fprintf (stderr, "\n");
  fprintf (stderr, "All options must be set.\n\n");
  fprintf (stderr, "No error checking yet, so be careful.\n\n");

  fprintf (stderr, "Usage: make_angresfunc [-hart]\n");
  fprintf (stderr, " -t type of angular response\n");
  fprintf (stderr, "    1: cosine (default)\n");
  fprintf (stderr, "    2: 2pi actinic flux\n");
  fprintf (stderr, "    3: 4pi actinic flux\n");
  fprintf (stderr, " -a angular output format\n");
  fprintf (stderr, "    1: angles (default)\n");
  fprintf (stderr, "    2: cosine of angle\n");
  fprintf (stderr, " -r resolution, in degrees\n");
  fprintf (stderr, " -h    Print this message.\n");  
}
